==> TikPy-0.3.tar.gz: TikPy-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'TikPy',         # How you named your package folder (MyLib)
  packages = ['TikPy'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Tiktok API. ',   # Give a short description about your library
  author = 'Vishwesh Kumar',                   # Type in your name
  author_email = 'vishwesh18119@iiitd.ac.in',      # Type in your E-Mail
  url = 'https://github.com/precog-recr/TikPy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/precog-recr/TikPy/archive/v_03.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'bs4',
          'newspaper3k'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    # 'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    # 'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> TikPy-0.5.tar.gz: TikPy-0.5/setup.py <==
from distutils.core import setup
setup(
  name = 'TikPy',         # How you named your package folder (MyLib)
  packages = ['TikPy'],   # Chose the same as "name"
  version = '0.5',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'https://github.com/precog-recr/TikPy/README.md',   # Give a short description about your library
  author = 'Vishwesh Kumar',                   # Type in your name
  author_email = 'vishwesh18119@iiitd.ac.in',      # Type in your E-Mail
  url = 'https://github.com/precog-recr/TikPy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/precog-recr/TikPy/archive/v_05.tar.gz',    # I explain this later on
  keywords = ['TikTok', 'API'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'bs4',
          'newspaper3k'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    # 'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    # 'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
